# Create some statistics from heater archive data:
# Time above/below setpoint, ...

open DATA, "ArchiveExport -fill dir kasemir:setpoint kasemir:tank |"
    or die "Cannot open data source\n";

$samples=0;
$total=0;
$last_seconds=0;
$above=0;
$at=0;
$below=0;
while (<DATA>)
{
    # Skip anything that doesn't start w/ time stamp
    next unless m/^[0-9].*/;
    ($date,$time,$setpoint,$readback) = split;

    if ($time =~ m/^([0-9][0-9]):([0-9][0-9]):([0-9][0-9]\.[0-9]*)/)
    {
	$h = $1;
	$m = $2;
	$s = $3;
	$seconds=($h*60.0+$m)*60.0+$s;
    }
    else
    {
	die "Cannot decode time string\n";
    }

    if ($last_seconds>0)
    {
	$passed = $seconds - $last_seconds;
	if ($readback > $setpoint+0.5)
	{
	    $above += $passed;
	}
	elsif ($readback < $setpoint-0.5)
	{
	    $below += $passed;
	}
	else
	{
	    $at += $passed;
	}
    }   
    $last_seconds = $seconds;
    ++$samples;
    $total += $readback;
    # print "$seconds - $time - $setpoint - $readback\n";
}

printf "Average temperature: %g\n", $total/$samples;
printf "Above setpoint: %g minutes\n", $above/60.0;
printf "Below setpoint: %g minutes\n", $below/60.0;
printf "At    setpoint: %g minutes\n", $at/60.0;
